#!/bin/bash
#
# run_install.sh
# Copyright (C) 2019 Uwe Schitt <uwe.schmitt@id.ethz.ch>
#
# Distributed under terms of the MIT license.
#

# from https://unix.stackexchange.com/questions/39623/
err() {
    echo "Error occurred:"
    awk 'NR>L-4 && NR<L+4 { printf "%-5d%3s%s\n",NR,(NR==L?">>>":""),$0 }' L=$1 $0
    exit 1
}
trap 'err $LINENO' ERR

WORKSHOP_TMP=${HOME}/.tmp/ml_workshop

if [[ ${MACHTYPE} == *darwin* ]]; then
    # local testing
    BASE_URL="file:///${PWD}"
else
    BASE_URL="https://sis.id.ethz.ch/mlw"
fi;

rm -rf ${WORKSHOP_TMP}/*

curl -# $BASE_URL/mlw_packages.yml > /tmp/mlw_packages.yml
curl -# $BASE_URL/setup_anaconda.sh | bash

mkdir -p $HOME/.tmp/ml_workshop

curl -# $BASE_URL/notebooks.tar.bz2 | tar -C ${WORKSHOP_TMP} -xjf -

cat >start_mlw.sh <<END
cd ${WORKSHOP_TMP}
/tmp/conda_envs/mlw/bin/jupyter notebook
END

chmod +x ./start_mlw.sh

cat >update_notebooks.sh <<END
rm -rf ${WORKSHOP_TMP}
mkdir -p ${WORKSHOP_TMP}
curl -# $BASE_URL/notebooks.tar.bz2 | tar -C ${WORKSHOP_TMP} -xjf -
END

chmod +x ./update_notebooks.sh

echo
echo
echo
echo
echo
echo
echo
echo
echo
echo
echo WILL START THE NOTEBOOK NOW.
echo
echo IN CASE YOU CLOSED THE BROWSER RUN
echo
echo             ./start_mlw.sh
echo
echo IN THE TERMINAL TO OPEN THE NOTEBOOKS AGAIN.
echo
echo PLEASE WRITE DOWN HOW THIS COMMAND, THEN PRESS ENTER TO CONTINUE
echo
read -p "PRESS ENTER"


./start_mlw.sh
