#! /bin/sh
#
# create_installer.sh
# Copyright (C) 2019 Uwe Schitt <uwe.schmitt@id.ethz.ch>
#
# Distributed under terms of the MIT license.
#

set -e

# files to include for installation:
INSTALLER_FILES="setup_anaconda.sh install.sh ../mlw_packages.yml"
NOTEBOOKS=??_*.ipynb

GRAPHICS="*.svg *.png *.jpg *.jpeg *.gif"
GRAPHICS+=" images/neuralnets/*.svg images/neuralnets/*.png images/neuralnets/*.jpg images/neuralnets/*.jpeg images/neuralnets/*.gif"

# settings remote server
URL_POSTFIX=mlw
URL_REMOTE_MACHINE=https://sis.id.ethz.ch/${URL_POSTFIX}/install.sh
REMOTE_LOGIN=w3_scientific@scientific.ethz.ch

REMOTE_WEB_FOLDER=htdocs/${URL_POSTFIX}
SCP_TARGET=${REMOTE_LOGIN}:${REMOTE_WEB_FOLDER}

# end of user settings, edits from here on only if you know what you do.

LOCAL_BUILD_FOLDER=/tmp/installer-build-tmp/

# create fresh folder structure to build archive with notebooks
rm -rf ${LOCAL_BUILD_FOLDER}
mkdir -p ${LOCAL_BUILD_FOLDER}/course
mkdir -p ${LOCAL_BUILD_FOLDER}/solutions

# create solution notebooks, copy originals and solutions
# to build folder
pushd .. >/dev/null

for NOTEBOOK in ${NOTEBOOKS}; do
    echo process ${NOTEBOOK}

    TARGET=${LOCAL_BUILD_FOLDER}/course/${NOTEBOOK}
    nb-filter-cells -i $NOTEBOOK -t solution -o ${TARGET}

    TARGET=${LOCAL_BUILD_FOLDER}/solutions/${NOTEBOOK%.ipynb}-with-solutions.ipynb
    cp $NOTEBOOK ${TARGET}
done

echo scp graphics

rsync -R ${GRAPHICS} ${LOCAL_BUILD_FOLDER}/solutions 2>/dev/null || true
rsync -R ${GRAPHICS} ${LOCAL_BUILD_FOLDER}/course 2>/dev/null || true

# zip notebooks and scp to remote machine
pushd ${LOCAL_BUILD_FOLDER}
echo
echo scp notebooks.tar.bz2
REMOTE_CMD="cat > ${REMOTE_WEB_FOLDER}/notebooks.tar.bz2"
tar jcf - . 2>/tmp/tar.err | ssh ${REMOTE_LOGIN} ${REMOTE_CMD}

popd >/dev/null
popd >/dev/null
echo

# also copy graphis to build folder


# copy other files needed by installer
echo
echo scp installer files
echo
scp ${INSTALLER_FILES} ${SCP_TARGET}

echo
echo TO SETUP A LINUX MACHINE FOR THE WORKSHOP ENTER
echo
echo "    curl ${URL_REMOTE_MACHINE} | bash"
echo
echo REPORT PROBLEMS TO schmittu@ethz.ch
echo
